import click

import demotools


@click.command()
@click.argument('val1')
@click.argument('val2')
@click.argument('val3')
def dt(val1, val2, val3):
    demotools.int_char_int(val1, val2, val3)


def main():
    dt()



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="demo-tools",
    version="0.0.1",
    author="mirrordust",
    # author_email="gsmr19re@outlook.com",
    description="A set of tools which demos for computer learning",
    long_description=long_description,
    long_description_content_type="text/markdown",
    # url="https://github.com/mirrordust/demo-tools",
    project_urls={
        # "Bug Tracker": "https://github.com/mirrordust/demo-tools/issues",
    },
    entry_points={
        "console_scripts": [
            "demo-tools=demotools.command_line:main",
            "dt=demotools.command_line:dt",
        ],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
)
